OC.L10N.register(
    "password_policy",
    {
    "Password is expired, please use forgot password method to reset" : "Истёк срок действия пароля. Для сброса пароля используйте функцию восстановления забытого пароля.",
    "Password must not have been used recently before." : "Пароль не должен был использоваться недавно.",
    "Password is among the 1,000,000 most common ones. Please make it unique." : "Пароль находится в списке 1 000 000 наиболее распространённых паролей. Придумайте что-нибудь более оригинальное.",
    "Password is present in compromised password list. Please choose a different password." : "Пароль присутствует в списке скомпрометированных паролей. Пожалуйста, выберите другой пароль.",
    "Password needs to be at least %s characters long." : "Длина пароля должна быть не менее %s символов",
    "Password needs to contain at least one numeric character." : "Пароль должен содержать хотя бы одну цифру.",
    "Password needs to contain at least one special character." : "Пароль должен содержать хотя бы один специальный символ.",
    "Password needs to contain at least one lower and one upper case character." : "В пароле должны присутствовать и прописные и строчные буквы.",
    "Password policy" : "Правила создания паролей",
    "Allows admins to configure a password policy" : "Разрешенные администраторы для конфигурирования политики паролей",
    "Allow admin to define certain pre-conditions for password, e.g. enforce a minimum length" : "Разрешить администратору определять определенные предварительные условия для пароля, например. обеспечить минимальную длину пароля",
    "General password policies" : "Общие правила использования паролей",
    "Add policy set" : "Добавить набор политик",
    "Login policies" : "Политики входа в систему",
    "Password history size" : "Размер истории паролей",
    "Number of passwords to keep (securely hashed) to prevent users from reusing previously used passwords." : "Количество сохраняемых паролей (надежно хэшированных), чтобы пользователи не могли повторно использовать ранее использованные пароли.",
    "Maximum login attempts" : "Максимальное количество попыток входа в систему",
    "Number of login attempts before the user account will be disabled until manual action is taken. (0 for no limit)" : "Количество попыток входа до блокировки учетной записи, снимаемой вручную. (0 — без ограничений)",
    "Please note, this option is meant to protect attacked accounts. Disabled accounts have to be re-enabled manually by administration. Attackers that try to guess passwords of accounts will have their IP address blocked by the bruteforce protection independent from this setting." : "Обратите внимание, эта настройка предназначена для защиты атакуемых учетных записей. Отключенные учетные записи включаются администратором вручную. IP-адреса злоумышленников, пытающихся угадать пароли учетных записей, будут блокироваться механизмом защиты от перебора независимо от этой настройки.",
    "Number of days until user password expires" : "Количество дней до истечения действия пароля",
    "Password expiration" : "Истечение срока действия пароля",
    "Warning: enabling password expiration is nowadays considered a security risk by several security agencies." : "Предупреждение: в настоящее время некоторые службы безопасности считают включение срока действия пароля угрозой безопасности.",
    "Remove policy" : "Удалить политику",
    "Minimum password length" : "Минимальная длина пароля",
    "Forbid common passwords" : "Запретить простые пароли",
    "Enforce upper and lower case characters" : "Должны присутствовать символы в разных регистрах",
    "Enforce numeric characters" : "Должны присутствовать цифры",
    "Enforce special characters" : "Должны присутствовать спецсимволы",
    "Check password against the list of breached passwords from haveibeenpwned.com" : "Проверять пароль по списку слабых паролей из базы сайта haveibeenpwnd.com",
    "This check creates a hash of the password and sends the first 5 characters of this hash to the haveibeenpwned.com API to retrieve a list of all hashes that start with those. Then it checks on the Nextcloud instance if the password hash is in the result set." : "Для проверки пароля создаётся его хеш, после чего первые 5 символов этого хеша передаются в API сайта hasibeenpwned.com. Полученные с сайта хеши паролей сравниваются с хешами паролей сервера Nextcloud.",
    "Account password policies" : "Политика использования паролей для учетных записей",
    "Share password policies" : "Политика общего доступа к паролям"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
